Struct amazon_sp_fulfillment_inbound::models::non_partnered_small_parcel_data_input::NonPartneredSmallParcelDataInput
source · [−]pub struct NonPartneredSmallParcelDataInput {
pub carrier_name: String,
pub package_list: Vec<NonPartneredSmallParcelPackageInput>,
}Expand description
NonPartneredSmallParcelDataInput : Information that you provide to Amazon about a Small Parcel shipment shipped by a carrier that has not partnered with Amazon.
Fields
carrier_name: StringThe carrier that you are using for the inbound shipment.
package_list: Vec<NonPartneredSmallParcelPackageInput>A list of package tracking information.
Implementations
sourceimpl NonPartneredSmallParcelDataInput
impl NonPartneredSmallParcelDataInput
sourcepub fn new(
carrier_name: String,
package_list: Vec<NonPartneredSmallParcelPackageInput>
) -> NonPartneredSmallParcelDataInput
pub fn new(
carrier_name: String,
package_list: Vec<NonPartneredSmallParcelPackageInput>
) -> NonPartneredSmallParcelDataInput
Information that you provide to Amazon about a Small Parcel shipment shipped by a carrier that has not partnered with Amazon.